@@ -1,3 +1,5 @@
+from typing import Any
+
 from django.utils.translation import gettext_lazy as _
 
 from django_api_client.settings import api_client_settings
@@ -8,15 +10,15 @@ from .exceptions import APINotFound
 class APIClientEndpointList:
     endpoints = []
 
-    def __init__(self, endpoint_name):
+    def __init__(self, endpoint_name: str) -> None:
         self.name = endpoint_name
 
-    def set_endpoint(self, api, endpoint_url):
+    def set_endpoint(self, api: Any, endpoint_url: str) -> None:
         endpoint = BaseEndpoint(api=api, endpoint=endpoint_url)
         setattr(self, self._get_endpoint_base_name(endpoint_url), endpoint)
         self.endpoints.append(endpoint)
 
-    def _get_endpoint_base_name(self, endpoint):
+    def _get_endpoint_base_name(self, endpoint: str) -> Any:
         words = [key for key in endpoint.split('?')[0].split('/') if key]
         response_name = words[-1]
         if '-' in response_name:
@@ -29,13 +31,12 @@ class APIClient:
     This class instantiates all endpoint classes
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: Any) -> None:
         """API object to communicate with API.
         """
         self.api = BaseAPI(**kwargs)
         endpoints = self._get_endpoints(kwargs)
         for endpoint_name in endpoints:
-            endpoint = None
             endpoint_urls = endpoints[endpoint_name]
             endpoint = APIClientEndpointList(endpoint_name)
             for endpoint_url in endpoint_urls:
@@ -43,7 +44,10 @@ class APIClient:
 
             setattr(self, endpoint_name, endpoint)
 
-    def _get_endpoints(self, kwargs):
+    def __repr__(self) -> str:
+        return f'<APIClient {self.api.api_name.title()}>'
+
+    def _get_endpoints(self, kwargs: dict) -> dict:
         endpoints = {}
         for endpoint_path in kwargs['endpoints']:
             endpoint_name = self._get_endpoint_base_name(endpoint_path)
@@ -52,7 +56,7 @@ class APIClient:
             endpoints[endpoint_name].append(endpoint_path)
         return endpoints
 
-    def _get_endpoint_base_name(self, endpoint):
+    def _get_endpoint_base_name(self, endpoint: str) -> str:
         words = [key for key in endpoint.split('/') if key]
         response_name = words[0]
         if response_name in [f'v{i}' for i in range(10)]:
@@ -63,11 +67,8 @@ class APIClient:
 
         return response_name
 
-    def __repr__(self):
-        return f'<APIClient {self.api.api_name.title()}>'
 
-
-def api_client_factory(api_name='', **kwargs):
+def api_client_factory(api_name: str = '', **kwargs: Any) -> APIClient:
     if not api_name:
         raise AttributeError(_('API name is required.'))
     api_configs = next((api for api in api_client_settings.apis if api['NAME'] == api_name), None)
